@@ -14,24 +14,24 @@
 """Crate a venv."""
 
 import argparse
-import os
 import venv
 from pathlib import Path
 
 
 def _parse_args() -> argparse.Namespace:
     parser = argparse.ArgumentParser(description=__doc__)
-    parser.add_argument('--destination-dir',
-                        type=Path,
-                        required=True,
-                        help='Path to venv directory.')
+    parser.add_argument(
+        '--destination-dir',
+        type=Path,
+        required=True,
+        help='Path to venv directory.',
+    )
     return parser.parse_args()
 
 
 def main(destination_dir: Path) -> None:
     if not destination_dir.is_dir():
-        use_symlinks = not os.name == 'nt'
-        venv.create(destination_dir, symlinks=use_symlinks, with_pip=True)
+        venv.create(destination_dir, symlinks=True, with_pip=True)
 
 
 if __name__ == '__main__':
