@@ -27,16 +27,21 @@ def pigweed_environment_parser() -> envparse.EnvironmentParser:
     parser.add_var('PW_EMOJI', type=envparse.strict_bool, default=False)
     parser.add_var('PW_ENVSETUP')
     parser.add_var('PW_ENVSETUP_FULL')
-    parser.add_var('PW_ENVSETUP_NO_BANNER',
-                   type=envparse.strict_bool,
-                   default=False)
-    parser.add_var('PW_ENVSETUP_QUIET',
-                   type=envparse.strict_bool,
-                   default=False)
+    parser.add_var(
+        'PW_ENVSETUP_NO_BANNER', type=envparse.strict_bool, default=False
+    )
+    parser.add_var(
+        'PW_ENVSETUP_QUIET', type=envparse.strict_bool, default=False
+    )
     parser.add_var('PW_ENVIRONMENT_ROOT')
     parser.add_var('PW_PACKAGE_ROOT')
     parser.add_var('PW_PROJECT_ROOT')
     parser.add_var('PW_ROOT')
+    parser.add_var(
+        'PW_DISABLE_ROOT_GIT_REPO_CHECK',
+        type=envparse.strict_bool,
+        default=False,
+    )
     parser.add_var('PW_SKIP_BOOTSTRAP')
     parser.add_var('PW_SUBPROCESS', type=envparse.strict_bool, default=False)
     parser.add_var('PW_USE_COLOR', type=envparse.strict_bool, default=False)
@@ -44,20 +49,21 @@ def pigweed_environment_parser() -> envparse.EnvironmentParser:
 
     parser.add_allowed_suffix('_CIPD_INSTALL_DIR')
 
-    parser.add_var('PW_ENVSETUP_DISABLE_SPINNER',
-                   type=envparse.strict_bool,
-                   default=False)
+    parser.add_var(
+        'PW_ENVSETUP_DISABLE_SPINNER', type=envparse.strict_bool, default=False
+    )
     parser.add_var('PW_DOCTOR_SKIP_CIPD_CHECKS')
-    parser.add_var('PW_ACTIVATE_SKIP_CHECKS',
-                   type=envparse.strict_bool,
-                   default=False)
+    parser.add_var(
+        'PW_ACTIVATE_SKIP_CHECKS', type=envparse.strict_bool, default=False
+    )
 
     parser.add_var('PW_BANNER_FUNC')
     parser.add_var('PW_BRANDING_BANNER')
     parser.add_var('PW_BRANDING_BANNER_COLOR', default='magenta')
 
-    parser.add_var('PW_PRESUBMIT_DISABLE_SUBPROCESS_CAPTURE',
-                   type=envparse.strict_bool)
+    parser.add_var(
+        'PW_PRESUBMIT_DISABLE_SUBPROCESS_CAPTURE', type=envparse.strict_bool
+    )
 
     parser.add_var('PW_CONSOLE_CONFIG_FILE')
     parser.add_var('PW_ENVIRONMENT_NO_ERROR_ON_UNRECOGNIZED')
