@@ -37,13 +37,22 @@ from prompt_toolkit.widgets import Box, TextArea
 
 from pygments.lexers.markup import RstLexer  # type: ignore
 from pygments.lexers.data import YamlLexer  # type: ignore
-import pw_console.widgets.mouse_handlers
+
+from pw_console.style import (
+    get_pane_indicator,
+)
+from pw_console.widgets import (
+    mouse_handlers,
+    to_keybind_indicator,
+)
 
 if TYPE_CHECKING:
     from pw_console.console_app import ConsoleApp
 
 _LOG = logging.getLogger(__package__)
 
+_PW_CONSOLE_MODULE = 'pw_console'
+
 
 def _longest_line_length(text):
     """Return the longest line in the given text."""
@@ -86,11 +95,13 @@ class HelpWindow(ConditionalContainer):
         help_text_area.control.key_bindings = key_bindings
         return help_text_area
 
-    def __init__(self,
-                 application: 'ConsoleApp',
-                 preamble: str = '',
-                 additional_help_text: str = '',
-                 title: str = '') -> None:
+    def __init__(
+        self,
+        application: 'ConsoleApp',
+        preamble: str = '',
+        additional_help_text: str = '',
+        title: str = '',
+    ) -> None:
         # Dict containing key = section title and value = list of key bindings.
         self.application: 'ConsoleApp' = application
         self.show_window: bool = False
@@ -106,8 +117,11 @@ class HelpWindow(ConditionalContainer):
         self.additional_help_text: str = additional_help_text
         self.help_text: str = ''
 
-        self.max_additional_help_text_width: int = (_longest_line_length(
-            self.additional_help_text) if additional_help_text else 0)
+        self.max_additional_help_text_width: int = (
+            _longest_line_length(self.additional_help_text)
+            if additional_help_text
+            else 0
+        )
         self.max_description_width: int = 0
         self.max_key_list_width: int = 0
         self.max_line_length: int = 0
@@ -115,9 +129,11 @@ class HelpWindow(ConditionalContainer):
         self.help_text_area: TextArea = self._create_help_text_area()
 
         close_mouse_handler = functools.partial(
-            pw_console.widgets.mouse_handlers.on_click, self.toggle_display)
+            mouse_handlers.on_click, self.toggle_display
+        )
         copy_mouse_handler = functools.partial(
-            pw_console.widgets.mouse_handlers.on_click, self.copy_all_text)
+            mouse_handlers.on_click, self.copy_all_text
+        )
 
         toolbar_padding = 1
         toolbar_title = ' ' * toolbar_padding
@@ -125,25 +141,33 @@ class HelpWindow(ConditionalContainer):
 
         buttons = []
         buttons.extend(
-            pw_console.widgets.checkbox.to_keybind_indicator(
+            to_keybind_indicator(
                 'Ctrl-c',
                 'Copy All',
                 copy_mouse_handler,
-                base_style='class:toolbar-button-active'))
+                base_style='class:toolbar-button-active',
+            )
+        )
         buttons.append(('', '  '))
         buttons.extend(
-            pw_console.widgets.checkbox.to_keybind_indicator(
+            to_keybind_indicator(
                 'q',
                 'Close',
                 close_mouse_handler,
-                base_style='class:toolbar-button-active'))
+                base_style='class:toolbar-button-active',
+            )
+        )
         top_toolbar = VSplit(
             [
                 Window(
                     content=FormattedTextControl(
                         # [('', toolbar_title)]
-                        functools.partial(pw_console.style.get_pane_indicator,
-                                          self, toolbar_title)),
+                        functools.partial(
+                            get_pane_indicator,
+                            self,
+                            toolbar_title,
+                        )
+                    ),
                     align=WindowAlign.LEFT,
                     dont_extend_width=True,
                 ),
@@ -162,17 +186,19 @@ class HelpWindow(ConditionalContainer):
             style='class:toolbar_active',
         )
 
-        self.container = HSplit([
-            top_toolbar,
-            Box(
-                body=DynamicContainer(lambda: self.help_text_area),
-                padding=Dimension(preferred=1, max=1),
-                padding_bottom=0,
-                padding_top=0,
-                char=' ',
-                style='class:frame.border',  # Same style used for Frame.
-            ),
-        ])
+        self.container = HSplit(
+            [
+                top_toolbar,
+                Box(
+                    body=DynamicContainer(lambda: self.help_text_area),
+                    padding=Dimension(preferred=1, max=1),
+                    padding_bottom=0,
+                    padding_top=0,
+                    char=' ',
+                    style='class:frame.border',  # Same style used for Frame.
+                ),
+            ]
+        )
 
         super().__init__(
             self.container,
@@ -196,7 +222,8 @@ class HelpWindow(ConditionalContainer):
     def copy_all_text(self):
         """Copy all text in the Python input to the system clipboard."""
         self.application.application.clipboard.set_text(
-            self.help_text_area.buffer.text)
+            self.help_text_area.buffer.text
+        )
 
     def toggle_display(self):
         """Toggle visibility of this help window."""
@@ -227,20 +254,24 @@ class HelpWindow(ConditionalContainer):
         scrollbar_width = 1
 
         desired_width = self.max_line_length + (
-            left_side_frame_and_padding_width +
-            right_side_frame_and_padding_width + scrollbar_padding +
-            scrollbar_width)
+            left_side_frame_and_padding_width
+            + right_side_frame_and_padding_width
+            + scrollbar_padding
+            + scrollbar_width
+        )
         desired_width = max(60, desired_width)
 
         window_manager_width = (
-            self.application.window_manager.current_window_manager_width)
+            self.application.window_manager.current_window_manager_width
+        )
         if not window_manager_width:
             window_manager_width = 80
         return min(desired_width, window_manager_width)
 
     def load_user_guide(self):
-        rstdoc_text = importlib.resources.read_text('pw_console.docs',
-                                                    'user_guide.rst')
+        rstdoc_text = importlib.resources.read_text(
+            f'{_PW_CONSOLE_MODULE}.docs', 'user_guide.rst'
+        )
         max_line_length = 0
         rst_text = ''
         for line in rstdoc_text.splitlines():
@@ -284,8 +315,9 @@ class HelpWindow(ConditionalContainer):
         self.max_line_length = _longest_line_length(self.help_text)
 
         # Replace the TextArea content.
-        self.help_text_area.buffer.document = Document(text=self.help_text,
-                                                       cursor_position=0)
+        self.help_text_area.buffer.document = Document(
+            text=self.help_text, cursor_position=0
+        )
 
         return self.help_text
 
@@ -319,11 +351,13 @@ class HelpWindow(ConditionalContainer):
 
             # Get the existing list of keys for this function or make a new one.
             key_list = self.help_text_sections[section_name].get(
-                description, list())
+                description, list()
+            )
 
             # Save the name of the key e.g. F1, q, ControlQ, ControlUp
             key_name = ' '.join(
-                [getattr(key, 'name', str(key)) for key in binding.keys])
+                [getattr(key, 'name', str(key)) for key in binding.keys]
+            )
             key_name = key_name.replace('Control', 'Ctrl-')
             key_name = key_name.replace('Shift', 'Shift-')
             key_name = key_name.replace('Escape ', 'Alt-')
