@@ -16,6 +16,7 @@
 import functools
 import logging
 import re
+import time
 from typing import (
     Any,
     Callable,
@@ -41,15 +42,17 @@ from prompt_toolkit.layout import (
     ConditionalContainer,
     Float,
     FloatContainer,
+    FormattedTextControl,
+    HSplit,
     UIContent,
     UIControl,
     VerticalAlign,
+    VSplit,
     Window,
+    WindowAlign,
 )
 from prompt_toolkit.mouse_events import MouseEvent, MouseEventType, MouseButton
 
-import pw_console.widgets.checkbox
-import pw_console.style
 from pw_console.log_view import LogView
 from pw_console.log_pane_toolbars import (
     LineInfoBar,
@@ -60,13 +63,22 @@ from pw_console.log_pane_selection_dialog import LogPaneSelectionDialog
 from pw_console.log_store import LogStore
 from pw_console.search_toolbar import SearchToolbar
 from pw_console.filter_toolbar import FilterToolbar
+
+from pw_console.style import (
+    get_pane_style,
+)
 from pw_console.widgets import (
     ToolbarButton,
     WindowPane,
     WindowPaneHSplit,
     WindowPaneToolbar,
+    create_border,
+    mouse_handlers,
+    to_checkbox_text,
+    to_keybind_indicator,
 )
 
+
 if TYPE_CHECKING:
     from pw_console.console_app import ConsoleApp
 
@@ -76,6 +88,7 @@ _LOG = logging.getLogger(__package__)
 
 class LogContentControl(UIControl):
     """LogPane prompt_toolkit UIControl for displaying LogContainer lines."""
+
     def __init__(self, log_pane: 'LogPane') -> None:
         # pylint: disable=too-many-locals
         self.log_pane = log_pane
@@ -122,7 +135,8 @@ class LogContentControl(UIControl):
             """Remove log pane."""
             if self.log_pane.is_a_duplicate:
                 self.log_pane.application.window_manager.remove_pane(
-                    self.log_pane)
+                    self.log_pane
+                )
 
         @register('log-pane.clear-history', key_bindings)
         def _clear_history(_event: KeyPressEvent) -> None:
@@ -144,6 +158,11 @@ class LogContentControl(UIControl):
             """Toggle log line following."""
             self.log_pane.toggle_follow()
 
+        @register('log-pane.toggle-web-browser', key_bindings)
+        def _toggle_browser(_event: KeyPressEvent) -> None:
+            """View logs in browser."""
+            self.log_pane.toggle_websocket_server()
+
         @register('log-pane.move-cursor-up', key_bindings)
         def _up(_event: KeyPressEvent) -> None:
             """Move cursor up."""
@@ -248,9 +267,11 @@ class LogContentControl(UIControl):
 
         # Create a UIContent instance if none exists
         if self.uicontent is None:
-            self.uicontent = UIContent(get_line=lambda i: self.lines[i],
-                                       line_count=len(self.lines),
-                                       show_cursor=False)
+            self.uicontent = UIContent(
+                get_line=lambda i: self.lines[i],
+                line_count=len(self.lines),
+                show_cursor=False,
+            )
 
         # Update line_count
         self.uicontent.line_count = len(self.lines)
@@ -265,13 +286,17 @@ class LogContentControl(UIControl):
         # 1. check if a mouse drag just completed.
         # 2. If not in focus, switch focus to this log pane
         #    If in focus, move the cursor to that position.
-        if (mouse_event.event_type == MouseEventType.MOUSE_UP
-                and mouse_event.button == MouseButton.LEFT):
+        if (
+            mouse_event.event_type == MouseEventType.MOUSE_UP
+            and mouse_event.button == MouseButton.LEFT
+        ):
 
             # If a drag was in progress and this is the first mouse release
             # press, set the stop flag.
-            if (self.visual_select_mode_drag_start
-                    and not self.visual_select_mode_drag_stop):
+            if (
+                self.visual_select_mode_drag_start
+                and not self.visual_select_mode_drag_stop
+            ):
                 self.visual_select_mode_drag_stop = True
 
             if not has_focus(self)():
@@ -295,11 +320,15 @@ class LogContentControl(UIControl):
 
         # Mouse drag with left button should start selecting lines.
         # The log pane does not need to be in focus to start this.
-        if (mouse_event.event_type == MouseEventType.MOUSE_MOVE
-                and mouse_event.button == MouseButton.LEFT):
+        if (
+            mouse_event.event_type == MouseEventType.MOUSE_MOVE
+            and mouse_event.button == MouseButton.LEFT
+        ):
             # If a previous mouse drag was completed, clear the selection.
-            if (self.visual_select_mode_drag_start
-                    and self.visual_select_mode_drag_stop):
+            if (
+                self.visual_select_mode_drag_start
+                and self.visual_select_mode_drag_stop
+            ):
                 self.log_pane.log_view.clear_visual_selection()
             # Drag select in progress, set flags accordingly.
             self.visual_select_mode_drag_start = True
@@ -325,6 +354,161 @@ class LogContentControl(UIControl):
         return NotImplemented
 
 
+class LogPaneWebsocketDialog(ConditionalContainer):
+    """Dialog box for showing the websocket URL."""
+
+    # Height of the dialog box contens in lines of text.
+    DIALOG_HEIGHT = 2
+
+    def __init__(self, log_pane: 'LogPane'):
+        self.log_pane = log_pane
+
+        self._last_action_message: str = ''
+        self._last_action_time: float = 0
+
+        info_bar_control = FormattedTextControl(self.get_info_fragments)
+        info_bar_window = Window(
+            content=info_bar_control,
+            height=1,
+            align=WindowAlign.LEFT,
+            dont_extend_width=False,
+        )
+
+        message_bar_control = FormattedTextControl(self.get_message_fragments)
+        message_bar_window = Window(
+            content=message_bar_control,
+            height=1,
+            align=WindowAlign.RIGHT,
+            dont_extend_width=False,
+        )
+
+        action_bar_control = FormattedTextControl(self.get_action_fragments)
+        action_bar_window = Window(
+            content=action_bar_control,
+            height=1,
+            align=WindowAlign.RIGHT,
+            dont_extend_width=True,
+        )
+
+        super().__init__(
+            create_border(
+                HSplit(
+                    [
+                        info_bar_window,
+                        VSplit([message_bar_window, action_bar_window]),
+                    ],
+                    height=LogPaneWebsocketDialog.DIALOG_HEIGHT,
+                    style='class:saveas-dialog',
+                ),
+                content_height=LogPaneWebsocketDialog.DIALOG_HEIGHT,
+                title='Websocket Log Server',
+                border_style='class:saveas-dialog-border',
+                left_margin_columns=1,
+            ),
+            filter=Condition(lambda: self.log_pane.websocket_dialog_active),
+        )
+
+    def focus_self(self) -> None:
+        # Nothing in this dialog can be focused, focus on the parent log_pane
+        # instead.
+        self.log_pane.application.focus_on_container(self.log_pane)
+
+    def close_dialog(self) -> None:
+        """Close this dialog."""
+        self.log_pane.toggle_websocket_server()
+        self.log_pane.websocket_dialog_active = False
+        self.log_pane.application.focus_on_container(self.log_pane)
+        self.log_pane.redraw_ui()
+
+    def _set_action_message(self, text: str) -> None:
+        self._last_action_time = time.time()
+        self._last_action_message = text
+
+    def copy_url_to_clipboard(self) -> None:
+        self.log_pane.application.application.clipboard.set_text(
+            self.log_pane.log_view.get_web_socket_url()
+        )
+        self._set_action_message('Copied!')
+
+    def get_message_fragments(self):
+        """Return FormattedText with the last action message."""
+        # Mouse handlers
+        focus = functools.partial(mouse_handlers.on_click, self.focus_self)
+        # Separator should have the focus mouse handler so clicking on any
+        # whitespace focuses the input field.
+        separator_text = ('', '  ', focus)
+
+        if self._last_action_time + 10 > time.time():
+            return [
+                ('class:theme-fg-yellow', self._last_action_message, focus),
+                separator_text,
+            ]
+        return [separator_text]
+
+    def get_info_fragments(self):
+        """Return FormattedText with current URL info."""
+        # Mouse handlers
+        focus = functools.partial(mouse_handlers.on_click, self.focus_self)
+        # Separator should have the focus mouse handler so clicking on any
+        # whitespace focuses the input field.
+        separator_text = ('', '  ', focus)
+
+        fragments = [
+            ('class:saveas-dialog-setting', 'URL:  ', focus),
+            (
+                'class:saveas-dialog-title',
+                self.log_pane.log_view.get_web_socket_url(),
+                focus,
+            ),
+            separator_text,
+        ]
+        return fragments
+
+    def get_action_fragments(self):
+        """Return FormattedText with the action buttons."""
+        # Mouse handlers
+        focus = functools.partial(mouse_handlers.on_click, self.focus_self)
+        cancel = functools.partial(mouse_handlers.on_click, self.close_dialog)
+        copy = functools.partial(
+            mouse_handlers.on_click,
+            self.copy_url_to_clipboard,
+        )
+
+        # Separator should have the focus mouse handler so clicking on any
+        # whitespace focuses the input field.
+        separator_text = ('', '  ', focus)
+
+        # Default button style
+        button_style = 'class:toolbar-button-inactive'
+
+        fragments = []
+
+        # Action buttons
+        fragments.extend(
+            to_keybind_indicator(
+                key=None,
+                description='Stop',
+                mouse_handler=cancel,
+                base_style=button_style,
+            )
+        )
+
+        fragments.append(separator_text)
+        fragments.extend(
+            to_keybind_indicator(
+                key=None,
+                description='Copy to Clipboard',
+                mouse_handler=copy,
+                base_style=button_style,
+            )
+        )
+
+        # One space separator
+        fragments.append(('', ' ', focus))
+
+        return fragments
+
+
 class LogPane(WindowPane):
     """LogPane class."""
 
@@ -344,9 +528,9 @@ class LogPane(WindowPane):
         self.is_a_duplicate = False
 
         # Create the log container which stores and handles incoming logs.
-        self.log_view: LogView = LogView(self,
-                                         self.application,
-                                         log_store=log_store)
+        self.log_view: LogView = LogView(
+            self, self.application, log_store=log_store
+        )
 
         # Log pane size variables. These are updated just befor rendering the
         # pane by the LogLineHSplit class.
@@ -364,35 +548,60 @@ class LogPane(WindowPane):
         self.saveas_dialog_active = False
         self.visual_selection_dialog = LogPaneSelectionDialog(self)
 
+        self.websocket_dialog = LogPaneWebsocketDialog(self)
+        self.websocket_dialog_active = False
+
         # Table header bar, only shown if table view is active.
         self.table_header_toolbar = TableToolbar(self)
 
         # Create the bottom toolbar for the whole log pane.
         self.bottom_toolbar = WindowPaneToolbar(self)
         self.bottom_toolbar.add_button(
-            ToolbarButton('/', 'Search', self.start_search))
+            ToolbarButton('/', 'Search', self.start_search)
+        )
         self.bottom_toolbar.add_button(
-            ToolbarButton('Ctrl-o', 'Save', self.start_saveas))
+            ToolbarButton('Ctrl-o', 'Save', self.start_saveas)
+        )
         self.bottom_toolbar.add_button(
-            ToolbarButton('f',
-                          'Follow',
-                          self.toggle_follow,
-                          is_checkbox=True,
-                          checked=lambda: self.log_view.follow))
+            ToolbarButton(
+                'f',
+                'Follow',
+                self.toggle_follow,
+                is_checkbox=True,
+                checked=lambda: self.log_view.follow,
+            )
+        )
         self.bottom_toolbar.add_button(
-            ToolbarButton('t',
-                          'Table',
-                          self.toggle_table_view,
-                          is_checkbox=True,
-                          checked=lambda: self.table_view))
+            ToolbarButton(
+                't',
+                'Table',
+                self.toggle_table_view,
+                is_checkbox=True,
+                checked=lambda: self.table_view,
+            )
+        )
         self.bottom_toolbar.add_button(
-            ToolbarButton('w',
-                          'Wrap',
-                          self.toggle_wrap_lines,
-                          is_checkbox=True,
-                          checked=lambda: self.wrap_lines))
+            ToolbarButton(
+                'w',
+                'Wrap',
+                self.toggle_wrap_lines,
+                is_checkbox=True,
+                checked=lambda: self.wrap_lines,
+            )
+        )
         self.bottom_toolbar.add_button(
-            ToolbarButton('C', 'Clear', self.clear_history))
+            ToolbarButton('C', 'Clear', self.clear_history)
+        )
+
+        self.bottom_toolbar.add_button(
+            ToolbarButton(
+                'Shift-o',
+                'Open in browser',
+                self.toggle_websocket_server,
+                is_checkbox=True,
+                checked=lambda: self.log_view.websocket_running,
+            )
+        )
 
         self.log_content_control = LogContentControl(self)
 
@@ -414,7 +623,7 @@ class LogPane(WindowPane):
             dont_extend_width=False,
             # Needed for log lines ANSI sequences that don't specify foreground
             # or background colors.
-            style=functools.partial(pw_console.style.get_pane_style, self),
+            style=functools.partial(get_pane_style, self),
         )
 
         # Root level container
@@ -434,25 +643,39 @@ class LogPane(WindowPane):
                     align=VerticalAlign.BOTTOM,
                     height=lambda: self.height,
                     width=lambda: self.width,
-                    style=functools.partial(pw_console.style.get_pane_style,
-                                            self),
+                    style=functools.partial(get_pane_style, self),
                 ),
                 floats=[
                     Float(top=0, right=0, height=1, content=LineInfoBar(self)),
-                    Float(top=0,
-                          right=0,
-                          height=LogPaneSelectionDialog.DIALOG_HEIGHT,
-                          content=self.visual_selection_dialog),
-                    Float(top=3,
-                          left=2,
-                          right=2,
-                          height=LogPaneSaveAsDialog.DIALOG_HEIGHT + 2,
-                          content=self.saveas_dialog),
-                ]),
-            filter=Condition(lambda: self.show_pane))
+                    Float(
+                        top=0,
+                        right=0,
+                        height=LogPaneSelectionDialog.DIALOG_HEIGHT,
+                        content=self.visual_selection_dialog,
+                    ),
+                    Float(
+                        top=3,
+                        left=2,
+                        right=2,
+                        height=LogPaneSaveAsDialog.DIALOG_HEIGHT + 2,
+                        content=self.saveas_dialog,
+                    ),
+                    Float(
+                        top=1,
+                        left=2,
+                        right=2,
+                        height=LogPaneWebsocketDialog.DIALOG_HEIGHT + 2,
+                        content=self.websocket_dialog,
+                    ),
+                ],
+            ),
+            filter=Condition(lambda: self.show_pane),
+        )
 
     @property
     def table_view(self):
+        if self.log_view.websocket_running:
+            return False
         return self._table_view
 
     @table_view.setter
@@ -466,10 +689,12 @@ class LogPane(WindowPane):
         # List active filters
         if self.log_view.filtering_on:
             title += ' (FILTERS: '
-            title += ' '.join([
-                log_filter.pattern()
-                for log_filter in self.log_view.filters.values()
-            ])
+            title += ' '.join(
+                [
+                    log_filter.pattern()
+                    for log_filter in self.log_view.filters.values()
+                ]
+            )
             title += ')'
         return title
 
@@ -491,6 +716,8 @@ class LogPane(WindowPane):
 
     def start_search(self):
         """Show the search bar to begin a search."""
+        if self.log_view.websocket_running:
+            return
         # Show the search bar
         self.search_bar_active = True
         # Focus on the search bar
@@ -508,8 +735,10 @@ class LogPane(WindowPane):
 
     def pane_resized(self) -> bool:
         """Return True if the current window size has changed."""
-        return (self.last_log_pane_width != self.current_log_pane_width
-                or self.last_log_pane_height != self.current_log_pane_height)
+        return (
+            self.last_log_pane_width != self.current_log_pane_width
+            or self.last_log_pane_height != self.current_log_pane_height
+        )
 
     def update_pane_size(self, width, height):
         """Save width and height of the log pane for the current UI render
@@ -551,13 +780,26 @@ class LogPane(WindowPane):
         self.log_view.clear_scrollback()
         self.redraw_ui()
 
+    def toggle_websocket_server(self):
+        """Start or stop websocket server to send logs."""
+        if self.log_view.websocket_running:
+            self.log_view.stop_websocket_thread()
+            self.websocket_dialog_active = False
+        else:
+            self.search_toolbar.close_search_bar()
+            self.log_view.start_websocket_thread()
+            self.application.start_http_server()
+            self.saveas_dialog_active = False
+            self.websocket_dialog_active = True
+
     def get_all_key_bindings(self) -> List:
         """Return all keybinds for this pane."""
         # Return log content control keybindings
         return [self.log_content_control.get_key_bindings()]
 
     def get_window_menu_options(
-            self) -> List[Tuple[str, Union[Callable, None]]]:
+        self,
+    ) -> List[Tuple[str, Union[Callable, None]]]:
         """Return all menu options for the log pane."""
 
         options = [
@@ -570,22 +812,30 @@ class LogPane(WindowPane):
             ('-', None),
             (
                 '{check} Line wrapping'.format(
-                    check=pw_console.widgets.checkbox.to_checkbox_text(
-                        self.wrap_lines, end='')),
+                    check=to_checkbox_text(self.wrap_lines, end='')
+                ),
                 self.toggle_wrap_lines,
             ),
             (
                 '{check} Table view'.format(
-                    check=pw_console.widgets.checkbox.to_checkbox_text(
-                        self._table_view, end='')),
+                    check=to_checkbox_text(self._table_view, end='')
+                ),
                 self.toggle_table_view,
             ),
             (
                 '{check} Follow'.format(
-                    check=pw_console.widgets.checkbox.to_checkbox_text(
-                        self.log_view.follow, end='')),
+                    check=to_checkbox_text(self.log_view.follow, end='')
+                ),
                 self.toggle_follow,
             ),
+            (
+                '{check} Open in web browser'.format(
+                    check=to_checkbox_text(
+                        self.log_view.websocket_running, end=''
+                    )
+                ),
+                self.toggle_websocket_server,
+            ),
             # Menu separator
             ('-', None),
             (
@@ -598,11 +848,14 @@ class LogPane(WindowPane):
             ),
         ]
         if self.is_a_duplicate:
-            options += [(
-                'Remove/Delete pane',
-                functools.partial(self.application.window_manager.remove_pane,
-                                  self),
-            )]
+            options += [
+                (
+                    'Remove/Delete pane',
+                    functools.partial(
+                        self.application.window_manager.remove_pane, self
+                    ),
+                )
+            ]
 
         # Search / Filter section
         options += [
@@ -635,14 +888,17 @@ class LogPane(WindowPane):
                 if field == 'all':
                     field = None
                 if self.log_view.new_search(
-                        search_string,
-                        invert=inverted,
-                        field=field,
-                        search_matcher=matcher_name,
-                        interactive=False,
+                    search_string,
+                    invert=inverted,
+                    field=field,
+                    search_matcher=matcher_name,
+                    interactive=False,
                 ):
                     self.log_view.install_new_filter()
 
+        # Trigger any existing log messages to be added to the view.
+        self.log_view.new_logs_arrived()
+
     def create_duplicate(self) -> 'LogPane':
         """Create a duplicate of this LogView."""
         new_pane = LogPane(self.application, pane_title=self.pane_title())
@@ -667,9 +923,11 @@ class LogPane(WindowPane):
         # Add the new pane.
         self.application.window_manager.add_pane(new_pane)
 
-    def add_log_handler(self,
-                        logger: Union[str, logging.Logger],
-                        level_name: Optional[str] = None) -> None:
+    def add_log_handler(
+        self,
+        logger: Union[str, logging.Logger],
+        level_name: Optional[str] = None,
+    ) -> None:
         """Add a log handlers to this LogPane."""
 
         if isinstance(logger, logging.Logger):
@@ -681,7 +939,5 @@ class LogPane(WindowPane):
             if not hasattr(logging, level_name):
                 raise Exception(f'Unknown log level: {level_name}')
             logger_instance.level = getattr(logging, level_name, logging.INFO)
-        logger_instance.addHandler(self.log_view.log_store  # type: ignore
-                                   )
-        self.append_pane_subtitle(  # type: ignore
-            logger_instance.name)
+        logger_instance.addHandler(self.log_view.log_store)  # type: ignore
+        self.append_pane_subtitle(logger_instance.name)  # type: ignore
