@@ -32,8 +32,8 @@ from prompt_toolkit.layout import (
 from prompt_toolkit.mouse_events import MouseEvent, MouseEventType
 from prompt_toolkit.widgets import MenuItem
 
-import pw_console.widgets.border
 from pw_console.widgets import (
+    create_border,
     FloatingWindowPane,
     ToolbarButton,
     WindowPaneToolbar,
@@ -49,6 +49,7 @@ Twenty48Cell = Tuple[int, int, int]
 
 class Twenty48Game:
     """2048 Game."""
+
     def __init__(self) -> None:
         self.colors = {
             2: 'bg:#dd6',
@@ -279,6 +280,7 @@ class Twenty48Control(FormattedTextControl):
     This is the prompt_toolkit class that is responsible for drawing the 2048,
     handling keybindings if in focus, and mouse input.
     """
+
     def __init__(self, twenty48_pane: 'Twenty48Pane', *args, **kwargs) -> None:
         self.twenty48_pane = twenty48_pane
         self.game = self.twenty48_pane.game
@@ -370,12 +372,15 @@ class Twenty48Pane(FloatingWindowPane, PluginMixin):
     For an example see:
     https://pigweed.dev/pw_console/embedding.html#adding-plugins
     """
+
     def __init__(self, include_resize_handle: bool = True, **kwargs):
 
-        super().__init__(pane_title='2048',
-                         height=Dimension(preferred=17),
-                         width=Dimension(preferred=50),
-                         **kwargs)
+        super().__init__(
+            pane_title='2048',
+            height=Dimension(preferred=17),
+            width=Dimension(preferred=50),
+            **kwargs,
+        )
         self.game = Twenty48Game()
 
         # Hide by default.
@@ -384,7 +389,8 @@ class Twenty48Pane(FloatingWindowPane, PluginMixin):
         # Create a toolbar for display at the bottom of the 2048 window. It
         # will show the window title and buttons.
         self.bottom_toolbar = WindowPaneToolbar(
-            self, include_resize_handle=include_resize_handle)
+            self, include_resize_handle=include_resize_handle
+        )
 
         # Add a button to restart the game.
         self.bottom_toolbar.add_button(
@@ -393,7 +399,8 @@ class Twenty48Pane(FloatingWindowPane, PluginMixin):
                 description='Restart',  # Button name
                 # Function to run when clicked.
                 mouse_handler=self.game.reset_game,
-            ))
+            )
+        )
         # Add a button to restart the game.
         self.bottom_toolbar.add_button(
             ToolbarButton(
@@ -401,7 +408,8 @@ class Twenty48Pane(FloatingWindowPane, PluginMixin):
                 description='Quit',  # Button name
                 # Function to run when clicked.
                 mouse_handler=self.close_dialog,
-            ))
+            )
+        )
 
         # Every FormattedTextControl object (Twenty48Control) needs to live
         # inside a prompt_toolkit Window() instance. Here is where you specify
@@ -445,37 +453,44 @@ class Twenty48Pane(FloatingWindowPane, PluginMixin):
         # self.container is the root container that contains objects to be
         # rendered in the UI, one on top of the other.
         self.container = self._create_pane_container(
-            pw_console.widgets.border.create_border(
-                HSplit([
-                    # Vertical split content
-                    VSplit([
-                        # Left side will show the game board.
-                        self.twenty48_game_window,
-                        # Stats will be shown on the right.
-                        self.twenty48_stats_window,
-                    ]),
-                    # The bottom_toolbar is shown below the VSplit.
-                    self.bottom_toolbar,
-                ]),
+            create_border(
+                HSplit(
+                    [
+                        # Vertical split content
+                        VSplit(
+                            [
+                                # Left side will show the game board.
+                                self.twenty48_game_window,
+                                # Stats will be shown on the right.
+                                self.twenty48_stats_window,
+                            ]
+                        ),
+                        # The bottom_toolbar is shown below the VSplit.
+                        self.bottom_toolbar,
+                    ]
+                ),
                 title='2048',
                 border_style='class:command-runner-border',
                 # left_margin_columns=1,
                 # right_margin_columns=1,
-            ))
+            )
+        )
 
         self.dialog_content: List[AnyContainer] = [
             # Vertical split content
-            VSplit([
-                # Left side will show the game board.
-                self.twenty48_game_window,
-                # Stats will be shown on the right.
-                self.twenty48_stats_window,
-            ]),
+            VSplit(
+                [
+                    # Left side will show the game board.
+                    self.twenty48_game_window,
+                    # Stats will be shown on the right.
+                    self.twenty48_stats_window,
+                ]
+            ),
             # The bottom_toolbar is shown below the VSplit.
             self.bottom_toolbar,
         ]
         # Wrap the dialog content in a border
-        self.bordered_dialog_content = pw_console.widgets.border.create_border(
+        self.bordered_dialog_content = create_border(
             HSplit(self.dialog_content),
             title='2048',
             border_style='class:command-runner-border',
@@ -486,7 +501,8 @@ class Twenty48Pane(FloatingWindowPane, PluginMixin):
             self.container = self._create_pane_container(*self.dialog_content)
         else:
             self.container = self._create_pane_container(
-                self.bordered_dialog_content)
+                self.bordered_dialog_content
+            )
 
         # This plugin needs to run a task in the background periodically and
         # uses self.plugin_init() to set which function to run, and how often.
@@ -507,9 +523,9 @@ class Twenty48Pane(FloatingWindowPane, PluginMixin):
             MenuItem(
                 '[2048]',
                 children=[
-                    MenuItem('Example Top Level Menu',
-                             handler=None,
-                             disabled=True),
+                    MenuItem(
+                        'Example Top Level Menu', handler=None, disabled=True
+                    ),
                     # Menu separator
                     MenuItem('-', None),
                     MenuItem('Show/Hide 2048 Game', handler=_toggle_dialog),
