@@ -21,4 +21,4 @@ def set_symlink(target_path: Path, symlink_path: Path) -> None:
     if symlink_path.exists():
         os.remove(symlink_path)
 
-    os.symlink(target_path, symlink_path)
+    os.symlink(target_path, symlink_path, target_path.is_dir())
