@@ -29,8 +29,7 @@ try:
 except ImportError:
     # Append the pw_presubmit package path to the module search path to allow
     # running this module without installing the pw_presubmit package.
-    sys.path.append(os.path.dirname(os.path.dirname(
-        os.path.abspath(__file__))))
+    sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
     import pw_presubmit
 
 from pw_env_setup import python_packages
@@ -79,19 +78,30 @@ def _transform_lcov_file_paths(lcov_file: Path, repo_root: Path) -> str:
         file_string = line[3:].rstrip()
         source_file_path = Path(file_string)
 
+        # TODO(b/248257406) Remove once we drop support for Python 3.8.
+        def is_relative_to(path: Path, other: Path) -> bool:
+            try:
+                path.relative_to(other)
+                return True
+            except ValueError:
+                return False
+
         # Attempt to map a generated Python package source file to the root
         # source tree.
         # pylint: disable=no-member
-        if not source_file_path.is_relative_to(  # type: ignore[attr-defined]
-                repo_root):
+        if not is_relative_to(
+            source_file_path, repo_root  # type: ignore[attr-defined]
+        ):
             # pylint: enable=no-member
             source_file_path = repo_root / str(source_file_path).replace(
-                'python/gen/', '').replace('py.generated_python_package/', '')
+                'python/gen/', ''
+            ).replace('py.generated_python_package/', '')
 
         # If mapping fails don't modify this line.
         # pylint: disable=no-member
-        if not source_file_path.is_relative_to(  # type: ignore[attr-defined]
-                repo_root):
+        if not is_relative_to(
+            source_file_path, repo_root  # type: ignore[attr-defined]
+        ):
             # pylint: enable=no-member
             lcov_output += line + '\n'
             continue
@@ -120,7 +130,8 @@ def gn_python_test_coverage(ctx: PresubmitContext):
         # Leave existing coverage files in place; by default they are deleted.
         '--keep',
         *coverage_data_files,
-        cwd=ctx.output_dir)
+        cwd=ctx.output_dir,
+    )
     combined_data_file = ctx.output_dir / '.coverage'
     _LOG.info('Coverage data saved to: %s', combined_data_file.resolve())
 
@@ -129,7 +140,8 @@ def gn_python_test_coverage(ctx: PresubmitContext):
 
     # Output coverage percentage summary to the terminal of changed files.
     changed_python_files = list(
-        str(p) for p in ctx.paths if str(p).endswith('.py'))
+        str(p) for p in ctx.paths if str(p).endswith('.py')
+    )
     report_args = [
         'coverage',
         'report',
@@ -143,7 +155,8 @@ def gn_python_test_coverage(ctx: PresubmitContext):
     call('coverage', 'lcov', coverage_omit_patterns, cwd=ctx.output_dir)
     lcov_data_file = ctx.output_dir / 'coverage.lcov'
     lcov_data_file.write_text(
-        _transform_lcov_file_paths(lcov_data_file, repo_root=ctx.root))
+        _transform_lcov_file_paths(lcov_data_file, repo_root=ctx.root)
+    )
     _LOG.info('Coverage lcov saved to: %s', lcov_data_file.resolve())
 
     # Generate an html report
@@ -152,7 +165,7 @@ def gn_python_test_coverage(ctx: PresubmitContext):
     _LOG.info('Coverage html report saved to: %s', html_report.resolve())
 
 
-@filter_paths(endswith=_PYTHON_EXTENSIONS + ('.pylintrc', ))
+@filter_paths(endswith=_PYTHON_EXTENSIONS + ('.pylintrc',))
 def gn_python_lint(ctx: pw_presubmit.PresubmitContext) -> None:
     build.gn_gen(ctx)
     build.ninja(ctx, 'python.lint')
@@ -168,11 +181,13 @@ def check_python_versions(ctx: PresubmitContext):
     try:
         for arg in build.get_gn_args(ctx.output_dir):
             if arg['name'] == 'pw_build_PIP_CONSTRAINTS':
-                constraint_file = json.loads(
-                    arg['current']['value'])[0].strip('/')
+                constraint_file = json.loads(arg['current']['value'])[0].strip(
+                    '/'
+                )
             if arg['name'] == 'pw_build_PIP_REQUIREMENTS':
-                requirement_file = json.loads(
-                    arg['current']['value'])[0].strip('/')
+                requirement_file = json.loads(arg['current']['value'])[0].strip(
+                    '/'
+                )
     except json.JSONDecodeError:
         _LOG.warning('failed to parse GN args json')
         return
@@ -184,7 +199,11 @@ def check_python_versions(ctx: PresubmitContext):
     if requirement_file:
         ignored_requirements_arg = [(ctx.root / requirement_file)]
 
-    if python_packages.diff(
+    if (
+        python_packages.diff(
             expected=(ctx.root / constraint_file),
-            ignore_requirements_file=ignored_requirements_arg) != 0:
+            ignore_requirements_file=ignored_requirements_arg,
+        )
+        != 0
+    ):
         raise PresubmitFailure
