@@ -27,19 +27,26 @@ PLUGIN_VERSION = '0.3.0'
 
 RPC_NAMESPACE = '::pw::rpc'
 
+# todo-check: disable
 STUB_REQUEST_TODO = (
-    '// TODO: Read the request as appropriate for your application')
+    '// TODO: Read the request as appropriate for your application'
+)
 STUB_RESPONSE_TODO = (
-    '// TODO: Fill in the response as appropriate for your application')
+    '// TODO: Fill in the response as appropriate for your application'
+)
 STUB_WRITER_TODO = (
     '// TODO: Send responses with the writer as appropriate for your '
-    'application')
+    'application'
+)
 STUB_READER_TODO = (
     '// TODO: Set the client stream callback and send a response as '
-    'appropriate for your application')
+    'appropriate for your application'
+)
 STUB_READER_WRITER_TODO = (
     '// TODO: Set the client stream callback and send responses as '
-    'appropriate for your application')
+    'appropriate for your application'
+)
+# todo-check: enable
 
 
 def get_id(item: Union[ProtoService, ProtoServiceMethod]) -> str:
@@ -65,6 +72,7 @@ def client_call_type(method: ProtoServiceMethod, prefix: str) -> str:
 
 class CodeGenerator(abc.ABC):
     """Generates RPC code for services and clients."""
+
     def __init__(self, output_filename: str) -> None:
         self.output = OutputFile(output_filename)
 
@@ -122,13 +130,16 @@ class CodeGenerator(abc.ABC):
         """Additions to the private section of the outer generated class."""
 
 
-def generate_package(file_descriptor_proto, proto_package: ProtoNode,
-                     gen: CodeGenerator) -> None:
+def generate_package(
+    file_descriptor_proto, proto_package: ProtoNode, gen: CodeGenerator
+) -> None:
     """Generates service and client code for a package."""
     assert proto_package.type() == ProtoNode.Type.PACKAGE
 
-    gen.line(f'// {os.path.basename(gen.output.name())} automatically '
-             f'generated by {PLUGIN_NAME} {PLUGIN_VERSION}')
+    gen.line(
+        f'// {os.path.basename(gen.output.name())} automatically '
+        f'generated by {PLUGIN_NAME} {PLUGIN_VERSION}'
+    )
     gen.line(f'// on {datetime.now().isoformat()}')
     gen.line('// clang-format off')
     gen.line('#pragma once\n')
@@ -152,8 +163,8 @@ def generate_package(file_descriptor_proto, proto_package: ProtoNode,
 
     gen.line()
 
-    if proto_package.cpp_namespace():
-        file_namespace = proto_package.cpp_namespace()
+    if proto_package.cpp_namespace(codegen_subnamespace=None):
+        file_namespace = proto_package.cpp_namespace(codegen_subnamespace=None)
         if file_namespace.startswith('::'):
             file_namespace = file_namespace[2:]
 
@@ -165,7 +176,8 @@ def generate_package(file_descriptor_proto, proto_package: ProtoNode,
     gen.line()
 
     services = [
-        cast(ProtoService, node) for node in proto_package
+        cast(ProtoService, node)
+        for node in proto_package
         if node.type() == ProtoNode.Type.SERVICE
     ]
 
@@ -179,16 +191,21 @@ def generate_package(file_descriptor_proto, proto_package: ProtoNode,
         gen.line('}  // namespace ' + file_namespace)
 
     gen.line()
-    gen.line('// Specialize MethodInfo for each RPC to provide metadata at '
-             'compile time.')
+    gen.line(
+        '// Specialize MethodInfo for each RPC to provide metadata at '
+        'compile time.'
+    )
     for service in services:
         _generate_info(gen, file_namespace, service)
 
 
-def _generate_service_and_client(gen: CodeGenerator,
-                                 service: ProtoService) -> None:
-    gen.line('// Wrapper class that namespaces server and client code for '
-             'this RPC service.')
+def _generate_service_and_client(
+    gen: CodeGenerator, service: ProtoService
+) -> None:
+    gen.line(
+        '// Wrapper class that namespaces server and client code for '
+        'this RPC service.'
+    )
     gen.line(f'class {service.name()} final {{')
     gen.line(' public:')
 
@@ -226,23 +243,29 @@ def _check_method_name(method: ProtoServiceMethod) -> None:
             f'Attempted to compile `pw_rpc` for proto with method '
             f'`{method.name()}` inside a service of the same name. '
             '`pw_rpc` does not yet support methods with the same name as their '
-            'enclosing service.')
+            'enclosing service.'
+        )
     if method.name() in ('Service', 'ServiceInfo', 'Client'):
         raise ValueError(
             f'"{method.service().proto_path()}.{method.name()}" is not a '
             f'valid method name! The name "{method.name()}" is reserved '
-            'for internal use by pw_rpc.')
+            'for internal use by pw_rpc.'
+        )
 
 
 def _generate_client(gen: CodeGenerator, service: ProtoService) -> None:
     gen.line('// The Client is used to invoke RPCs for this service.')
-    gen.line(f'class Client final : public {RPC_NAMESPACE}::internal::'
-             'ServiceClient {')
+    gen.line(
+        f'class Client final : public {RPC_NAMESPACE}::internal::'
+        'ServiceClient {'
+    )
     gen.line(' public:')
 
     with gen.indent():
-        gen.line(f'constexpr Client({RPC_NAMESPACE}::Client& client,'
-                 ' uint32_t channel_id)')
+        gen.line(
+            f'constexpr Client({RPC_NAMESPACE}::Client& client,'
+            ' uint32_t channel_id)'
+        )
         gen.line('    : ServiceClient(client, channel_id) {}')
         gen.line()
         gen.line(f'using ServiceInfo = {service.name()};')
@@ -254,33 +277,43 @@ def _generate_client(gen: CodeGenerator, service: ProtoService) -> None:
     gen.line('};')
     gen.line()
 
-    gen.line('// Static functions for invoking RPCs on a pw_rpc server. '
-             'These functions are ')
-    gen.line('// equivalent to instantiating a Client and calling the '
-             'corresponding RPC.')
+    gen.line(
+        '// Static functions for invoking RPCs on a pw_rpc server. '
+        'These functions are '
+    )
+    gen.line(
+        '// equivalent to instantiating a Client and calling the '
+        'corresponding RPC.'
+    )
     for method in service.methods():
         _check_method_name(method)
         gen.client_static_function(method)
         gen.line()
 
 
-def _generate_info(gen: CodeGenerator, namespace: str,
-                   service: ProtoService) -> None:
+def _generate_info(
+    gen: CodeGenerator, namespace: str, service: ProtoService
+) -> None:
     """Generates MethodInfo for each method."""
     service_id = get_id(service)
     info = f'struct {RPC_NAMESPACE.lstrip(":")}::internal::MethodInfo'
 
     for method in service.methods():
         gen.line('template <>')
-        gen.line(f'{info}<{namespace}::pw_rpc::{gen.name()}::'
-                 f'{service.name()}::{method.name()}> {{')
+        gen.line(
+            f'{info}<{namespace}::pw_rpc::{gen.name()}::'
+            f'{service.name()}::{method.name()}> {{'
+        )
 
         with gen.indent():
             gen.line(f'static constexpr uint32_t kServiceId = {service_id};')
-            gen.line(f'static constexpr uint32_t kMethodId = '
-                     f'{get_id(method)};')
-            gen.line(f'static constexpr {RPC_NAMESPACE}::MethodType kType = '
-                     f'{method.type().cc_enum()};')
+            gen.line(
+                f'static constexpr uint32_t kMethodId = ' f'{get_id(method)};'
+            )
+            gen.line(
+                f'static constexpr {RPC_NAMESPACE}::MethodType kType = '
+                f'{method.type().cc_enum()};'
+            )
             gen.line()
 
             gen.line('template <typename ServiceImpl>')
@@ -291,9 +324,11 @@ def _generate_info(gen: CodeGenerator, namespace: str,
 
             gen.line('}')
 
-            gen.line('using GeneratedClient = '
-                     f'{"::" + namespace if namespace else ""}'
-                     f'::pw_rpc::{gen.name()}::{service.name()}::Client;')
+            gen.line(
+                'using GeneratedClient = '
+                f'{"::" + namespace if namespace else ""}'
+                f'::pw_rpc::{gen.name()}::{service.name()}::Client;'
+            )
 
             gen.method_info_specialization(method)
 
@@ -317,8 +352,10 @@ def _generate_service(gen: CodeGenerator, service: ProtoService) -> None:
         gen.service_aliases()
 
         gen.line()
-        gen.line(f'static constexpr const char* name() '
-                 f'{{ return "{service.name()}"; }}')
+        gen.line(
+            f'static constexpr const char* name() '
+            f'{{ return "{service.name()}"; }}'
+        )
         gen.line()
         gen.line(f'using ServiceInfo = {service.name()};')
         gen.line()
@@ -326,8 +363,10 @@ def _generate_service(gen: CodeGenerator, service: ProtoService) -> None:
     gen.line(' protected:')
 
     with gen.indent():
-        gen.line('constexpr Service() : '
-                 f'{base_class}(kServiceId, kPwRpcMethods) {{}}')
+        gen.line(
+            'constexpr Service() : '
+            f'{base_class}(kServiceId, kPwRpcMethods) {{}}'
+        )
 
     gen.line()
     gen.line(' private:')
@@ -337,9 +376,11 @@ def _generate_service(gen: CodeGenerator, service: ProtoService) -> None:
         gen.line()
 
         # Generate the method table
-        gen.line('static constexpr std::array<'
-                 f'{RPC_NAMESPACE}::internal::{gen.method_union_name()},'
-                 f' {len(service.methods())}> kPwRpcMethods = {{')
+        gen.line(
+            'static constexpr std::array<'
+            f'{RPC_NAMESPACE}::internal::{gen.method_union_name()},'
+            f' {len(service.methods())}> kPwRpcMethods = {{'
+        )
 
         with gen.indent(4):
             for method in service.methods():
@@ -355,8 +396,10 @@ def _generate_service(gen: CodeGenerator, service: ProtoService) -> None:
 
 def _method_lookup_table(gen: CodeGenerator, service: ProtoService) -> None:
     """Generates array of method IDs for looking up methods at compile time."""
-    gen.line('static constexpr std::array<uint32_t, '
-             f'{len(service.methods())}> kPwRpcMethodIds = {{')
+    gen.line(
+        'static constexpr std::array<uint32_t, '
+        f'{len(service.methods())}> kPwRpcMethodIds = {{'
+    )
 
     with gen.indent(4):
         for method in service.methods():
@@ -367,23 +410,26 @@ def _method_lookup_table(gen: CodeGenerator, service: ProtoService) -> None:
 
 class StubGenerator(abc.ABC):
     """Generates stub method implementations that can be copied-and-pasted."""
+
     @abc.abstractmethod
     def unary_signature(self, method: ProtoServiceMethod, prefix: str) -> str:
         """Returns the signature of this unary method."""
 
     @abc.abstractmethod
-    def unary_stub(self, method: ProtoServiceMethod,
-                   output: OutputFile) -> None:
+    def unary_stub(
+        self, method: ProtoServiceMethod, output: OutputFile
+    ) -> None:
         """Returns the stub for this unary method."""
 
     @abc.abstractmethod
-    def server_streaming_signature(self, method: ProtoServiceMethod,
-                                   prefix: str) -> str:
+    def server_streaming_signature(
+        self, method: ProtoServiceMethod, prefix: str
+    ) -> str:
         """Returns the signature of this server streaming method."""
 
     def server_streaming_stub(  # pylint: disable=no-self-use
-            self, unused_method: ProtoServiceMethod,
-            output: OutputFile) -> None:
+        self, unused_method: ProtoServiceMethod, output: OutputFile
+    ) -> None:
         """Returns the stub for this server streaming method."""
         output.write_line(STUB_REQUEST_TODO)
         output.write_line('static_cast<void>(request);')
@@ -391,25 +437,27 @@ class StubGenerator(abc.ABC):
         output.write_line('static_cast<void>(writer);')
 
     @abc.abstractmethod
-    def client_streaming_signature(self, method: ProtoServiceMethod,
-                                   prefix: str) -> str:
+    def client_streaming_signature(
+        self, method: ProtoServiceMethod, prefix: str
+    ) -> str:
         """Returns the signature of this client streaming method."""
 
     def client_streaming_stub(  # pylint: disable=no-self-use
-            self, unused_method: ProtoServiceMethod,
-            output: OutputFile) -> None:
+        self, unused_method: ProtoServiceMethod, output: OutputFile
+    ) -> None:
         """Returns the stub for this client streaming method."""
         output.write_line(STUB_READER_TODO)
         output.write_line('static_cast<void>(reader);')
 
     @abc.abstractmethod
-    def bidirectional_streaming_signature(self, method: ProtoServiceMethod,
-                                          prefix: str) -> str:
+    def bidirectional_streaming_signature(
+        self, method: ProtoServiceMethod, prefix: str
+    ) -> str:
         """Returns the signature of this bidirectional streaming method."""
 
     def bidirectional_streaming_stub(  # pylint: disable=no-self-use
-            self, unused_method: ProtoServiceMethod,
-            output: OutputFile) -> None:
+        self, unused_method: ProtoServiceMethod, output: OutputFile
+    ) -> None:
         """Returns the stub for this bidirectional streaming method."""
         output.write_line(STUB_READER_WRITER_TODO)
         output.write_line('static_cast<void>(reader_writer);')
@@ -426,8 +474,10 @@ def _select_stub_methods(gen: StubGenerator, method: ProtoServiceMethod):
         return gen.client_streaming_signature, gen.client_streaming_stub
 
     if method.type() is ProtoServiceMethod.Type.BIDIRECTIONAL_STREAMING:
-        return (gen.bidirectional_streaming_signature,
-                gen.bidirectional_streaming_stub)
+        return (
+            gen.bidirectional_streaming_signature,
+            gen.bidirectional_streaming_stub,
+        )
 
     raise NotImplementedError(f'Unrecognized method type {method.type()}')
 
@@ -453,11 +503,12 @@ _STUBS_COMMENT = r'''
 '''
 
 
-def package_stubs(proto_package: ProtoNode, gen: CodeGenerator,
-                  stub_generator: StubGenerator) -> None:
+def package_stubs(
+    proto_package: ProtoNode, gen: CodeGenerator, stub_generator: StubGenerator
+) -> None:
     """Generates the RPC stubs for a package."""
-    if proto_package.cpp_namespace():
-        file_ns = proto_package.cpp_namespace()
+    if proto_package.cpp_namespace(codegen_subnamespace=None):
+        file_ns = proto_package.cpp_namespace(codegen_subnamespace=None)
         if file_ns.startswith('::'):
             file_ns = file_ns[2:]
 
@@ -467,7 +518,8 @@ def package_stubs(proto_package: ProtoNode, gen: CodeGenerator,
         start_ns = finish_ns = lambda: None
 
     services = [
-        cast(ProtoService, node) for node in proto_package
+        cast(ProtoService, node)
+        for node in proto_package
         if node.type() == ProtoNode.Type.SERVICE
     ]
 
@@ -496,11 +548,14 @@ def package_stubs(proto_package: ProtoNode, gen: CodeGenerator,
     gen.line('#endif  // _PW_RPC_COMPILE_GENERATED_SERVICE_STUBS')
 
 
-def _service_declaration_stub(service: ProtoService, gen: CodeGenerator,
-                              stub_generator: StubGenerator) -> None:
+def _service_declaration_stub(
+    service: ProtoService, gen: CodeGenerator, stub_generator: StubGenerator
+) -> None:
     gen.line(f'// Implementation class for {service.proto_path()}.')
-    gen.line(f'class {service.name()} : public pw_rpc::{gen.name()}::'
-             f'{service.name()}::Service<{service.name()}> {{')
+    gen.line(
+        f'class {service.name()} : public pw_rpc::{gen.name()}::'
+        f'{service.name()}::Service<{service.name()}> {{'
+    )
 
     gen.line(' public:')
 
@@ -520,8 +575,9 @@ def _service_declaration_stub(service: ProtoService, gen: CodeGenerator,
     gen.line('};\n')
 
 
-def _service_definition_stub(service: ProtoService, gen: CodeGenerator,
-                             stub_generator: StubGenerator) -> None:
+def _service_definition_stub(
+    service: ProtoService, gen: CodeGenerator, stub_generator: StubGenerator
+) -> None:
     gen.line(f'// Method definitions for {service.proto_path()}.')
 
     blank_line = False
